@@ -8,10 +8,11 @@ Google Spreadsheets client library.
 
 """
 
-__version__ = '0.0.9'
+__version__ = '0.0.10'
 __author__ = 'Anton Burnashev'
 
 from .client import Client, login
 from .models import Spreadsheet, Worksheet, Cell
 from .exceptions import (GSpreadException, AuthenticationError,
-                         SpreadsheetNotFound, NoValidUrlKeyFound)
+                         SpreadsheetNotFound, NoValidUrlKeyFound,
+                         IncorrectCellLabel)
