@@ -1,9 +1,20 @@
+# -*- coding: utf-8 -*-
+
+"""
+gspread.httpsession
+~~~~~~~~~~~~~~~~~~~
+
+This module contains a class for working with http sessions.
+
+"""
+
 import urllib
 import urllib2
 
 class HTTPSession(object):
-    """Handles HTTP activity while keeping headers across requests.
+    """Handles HTTP activity while keeping headers persisting across requests.
 
+       :param headers: A dict with initial headers.
     """
     def __init__(self, headers=None):
         self.headers = headers or {}
