@@ -7,6 +7,7 @@ gspread.models
 This module contains common spreadsheets' models
 
 """
+import re
 
 from xml.etree import ElementTree
 from xml.etree.ElementTree import Element, SubElement
@@ -15,6 +16,7 @@ from .ns import _ns, _ns1
 from .urls import construct_url
 from .utils import finditem
 
+from .exceptions import IncorrectCellLabel
 
 class Spreadsheet(object):
     """A class for a spreadsheet object.
@@ -62,15 +64,52 @@ class Spreadsheet(object):
             self._fetch_sheets()
         return self._sheet_list[index]
 
+    @property
+    def sheet1(self):
+        """Shortcut property for getting the first worksheet."""
+        return self.get_worksheet(0)
+
 
 class Worksheet(object):
     """A class for worksheet object.
 
     """
-    def __init__(self, spreadsheet, feed_entry):
+    def __init__(self, spreadsheet, element):
         self.spreadsheet = spreadsheet
         self.client = spreadsheet.client
-        self.id = feed_entry.find(_ns('id')).text.split('/')[-1]
+        self._id = element.find(_ns('id')).text.split('/')[-1]
+        self._title = element.find(_ns('title')).text
+        self._element = element
+
+    def __repr__(self):
+        return '<%s "%s" id:%s>' % (self.__class__.__name__,
+                                     self.title,
+                                     self.id)
+
+    @property
+    def id(self):
+        """Id of a worksheet."""
+        return self._id
+
+    @property
+    def title(self):
+        """Title of a worksheet."""
+        return self._title
+
+    @property
+    def row_count(self):
+        """Number of rows"""
+        return int(self._element.find(_ns1('rowCount')).text)
+
+    @property
+    def col_count(self):
+        """Number of columns"""
+        return int(self._element.find(_ns1('colCount')).text)
+
+    @property
+    def updated(self):
+        """Updated time in RFC 3339 format"""
+        return self._element.find(_ns('updated')).text
 
     def get_id_fields(self):
         return {'spreadsheet_id': self.spreadsheet.id,
@@ -87,12 +126,47 @@ class Worksheet(object):
 
         return cells_list
 
+    _cell_addr_re = re.compile(r'([A-Za-z]+)(\d+)')
+    def _get_int_addr(self, label):
+        magic_number = 96
+        m = self._cell_addr_re.match(label)
+        if m:
+            column_label = m.group(1).lower()
+            row = int(m.group(2))
+
+            col = 0
+            for i, c in enumerate(reversed(column_label)):
+                col += (ord(c) - magic_number) * (26 ** i)
+        else:
+            raise IncorrectCellLabel(label)
+
+        return (row, col)
+
+    def acell(self, label):
+        """Returns an instance of a :class:`Cell`.
+
+        :param label: String with cell label in common format, e.g. 'B1'.
+                      Letter case is ignored.
+
+        Example:
+
+        >>> wks.acell('A1') # this could be 'a1' as well
+        <Cell R1C1 "I'm cell A1">
+
+        """
+        return self.cell(*(self._get_int_addr(label)))
+
     def cell(self, row, col):
         """Returns an instance of a :class:`Cell` positioned in `row`
            and `col` column.
 
-        :param row: Row number.
-        :param col: Column number.
+        :param row: Integer row number.
+        :param col: Integer column number.
+
+        Example:
+
+        >>> wks.cell(1, 1)
+        <Cell R1C1 "I'm cell A1">
 
         """
         feed = self.client.get_cells_cell_id_feed(self,
@@ -173,6 +247,21 @@ class Worksheet(object):
 
         return vals
 
+    def update_acell(self, label, val):
+        """Sets the new value to a cell.
+
+        :param label: String with cell label in common format, e.g. 'B1'.
+                      Letter case is ignored.
+        :param val: New value.
+
+        Example:
+
+        >>> wks.update_acell('A1', '42') # this could be 'a1' as well
+        <Cell R1C1 "I'm cell A1">
+
+        """
+        return self.update_cell(*(self._get_int_addr(label)), val=val)
+
     def update_cell(self, row, col, val):
         """Sets the new value to a cell.
 
